# VALORANT-Async-Client-API
![PyPI](https://img.shields.io/pypi/v/valorantclientapi?style=for-the-badge)
![PyPI - Downloads](https://img.shields.io/pypi/dm/valorantclientapi?style=for-the-badge)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/valorantclientapi?style=for-the-badge)
![PyPI - Status](https://img.shields.io/pypi/status/valorantclientAPI?style=for-the-badge)
![GitHub issues](https://img.shields.io/github/issues/jet612/VALORANT-Async-Client-API?style=for-the-badge)

Asynchronous Python wrapper for VALORANT's client API

# Documentation
Read the [Docs page](https://github.com/Jet612/VALORANT-Async-Client-API/tree/main/docs) to get started.

# Support
For support create an issue on [Github](https://github.com/Jet612/VALORANT-Async-Client-API) or Join the [Discord](https://discord.com/invite/mVXpvunBbF) and type in [#vca-general](https://discord.com/channels/1053395109581946930/1055236665930682448)

![GitHub contributors](https://img.shields.io/github/contributors/jet612/VALORANT-Async-Client-API)
![GitHub forks](https://img.shields.io/github/forks/jet612/VALORANT-Async-Client-API)
![GitHub Repo stars](https://img.shields.io/github/stars/jet612/VALORANT-Async-Client-API)


